@@ -2136,19 +2136,21 @@ function dcpCloudDebug(dur,easeby) {
 function profileSelectChange() {
     var ptyp = $("#in_profile").val();
     if (ptyp.match(/^diff-/)) {
-	$(".diffpar input").prop("disabled",false);
-	$(".diffpar").show();
-	$("#in_cutoff").prop('disabled',true);
-	$("#in_diff").prop('disabled',false);
-	$("#td_cutoff").hide();
-	$("#td_diff").show();
+	$("#td_cutoff").hide().find("#in_cutoff").prop('disabled',true);
+	$("#td_diff").show().find("#in_diff").prop('disabled',false);
+	$(".diffpar").show().find("input").prop('disabled',false);
     } else {
-	$(".diffpar input").prop("disabled",true);
-	$(".diffpar").hide();
-	$("#in_cutoff").prop('disabled',false);
-	$("#in_diff").prop('disabled',true);
-	$("#td_cutoff").show();
-	$("#td_diff").hide();
+	$(".diffpar").hide().find("input").prop('disabled',true);
+	$("#td_diff").hide().find("#in_diff").prop('disabled',true);
+	$("#td_cutoff").show().find("#in_cutoff").prop('disabled',false);
+    }
+
+    if (ptyp.match(/2$/)) {
+	//$("#td_onepass").show().find("input").prop('disabled',false);
+	$("#td_onepass").removeClass("disabled").find("input").prop('disabled',false);
+    } else {
+	//$("#td_onepass").hide().find("input").prop('disabled',true);
+	$("#td_onepass").addClass("disabled").find("input").prop('disabled',true);
     }
 }
 
